@@ -305,6 +305,9 @@ class Formatter:
         parts.append("END")
         return " ".join(parts)
 
+    def _cast(self, json, prec):
+        return "".join(["CAST(", self.dispatch(json[0]), " AS ", self.dispatch(json[1]), ")"])
+
     def _literal(self, json, prec):
         if isinstance(json, list):
             return "({0})".format(", ".join(
